@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: keymap.c,v 1.16.2.5 2003/05/19 19:11:28 nalin Exp $"
+#ident "$Id: keymap.c,v 1.19 2003/02/21 03:12:09 nalin Exp $"
 #include "../config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -124,8 +124,6 @@ static struct _vte_keymap_entry _vte_keymap_GDK_Tab[] = {
 };
 
 static struct _vte_keymap_entry _vte_keymap_GDK_Return[] = {
-	{cursor_all, keypad_all, fkey_all,
-	 VTE_META_MASK, _VTE_CAP_ESC "\n", 2, NULL},
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\n", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, "\r", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
@@ -152,22 +150,6 @@ static struct _vte_keymap_entry _vte_keymap_GDK_ISO_Left_Tab[] = {
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 
-static struct _vte_keymap_entry _vte_keymap_GDK_slash[] = {
-	{cursor_all, keypad_all, fkey_all,
-	 VTE_META_MASK, _VTE_CAP_ESC "/", 2, NULL},
-	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\037", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "/", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
-};
-
-static struct _vte_keymap_entry _vte_keymap_GDK_question[] = {
-	{cursor_all, keypad_all, fkey_all,
-	 VTE_META_MASK, _VTE_CAP_ESC "?", 2, NULL},
-	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\177", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "?", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
-};
-
 /* Various numeric keys enter control characters. */
 static struct _vte_keymap_entry _vte_keymap_GDK_2[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\0", 1, NULL},
@@ -440,7 +422,7 @@ static struct _vte_keymap_entry _vte_keymap_GDK_KP_Page_Down[] = {
 	 0, _VTE_CAP_CSI "6~", -1, NULL},
 	{cursor_all, keypad_default, fkey_sun, 0, _VTE_CAP_CSI "6z", -1, NULL},
 	{cursor_all, keypad_default, fkey_vt220, 0, "3", 1, NULL},
-	{cursor_all, keypad_app, fkey_notvt220, 0, _VTE_CAP_CSI "6~", -1, NULL},
+	{cursor_all, keypad_app, fkey_notvt220, 0, _VTE_CAP_CSI "5~", -1, NULL},
 	{cursor_all, keypad_app, fkey_vt220, 0, _VTE_CAP_SS3 "s", -1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
@@ -810,8 +792,6 @@ static struct _vte_keymap_group {
 	{GDK_Home,		_vte_keymap_GDK_Home},
 	{GDK_End,		_vte_keymap_GDK_End},
 	{GDK_Insert,		_vte_keymap_GDK_Insert},
-	{GDK_slash,		_vte_keymap_GDK_slash},
-	{GDK_question,		_vte_keymap_GDK_question},
 	/* GDK_Delete is all handled in code, due to funkiness. */
 	{GDK_Page_Up,		_vte_keymap_GDK_Page_Up},
 	{GDK_Page_Down,		_vte_keymap_GDK_Page_Down},
