@@ -19,7 +19,7 @@
 /* VTE accessibility object.  Based heavily on inspection of libzvt's
  * accessibility code. */
 
-#ident "$Id: vteaccess.c,v 1.30 2003/03/06 17:20:33 nalin Exp $"
+#ident "$Id: vteaccess.c,v 1.31 2003/04/15 16:40:15 nalin Exp $"
 #include "../config.h"
 #include <atk/atk.h>
 #include <gtk/gtk.h>
@@ -303,8 +303,6 @@ vte_terminal_accessible_update_private_data_if_needed(AtkObject *text,
 						"%ld.\n",
 						priv->snapshot_linebreaks->len,
 						attrs.row, i);
-					fprintf(stderr, "Cursor at (%ld, "
-						"%ld).\n", ccol, crow);
 				}
 #endif
 				g_array_append_val(priv->snapshot_linebreaks, i);
@@ -319,6 +317,11 @@ vte_terminal_accessible_update_private_data_if_needed(AtkObject *text,
 
 	/* Update the caret position. */
 	vte_terminal_get_cursor_position(terminal, &ccol, &crow);
+#ifdef VTE_DEBUG
+	if (_vte_debug_on(VTE_DEBUG_MISC)) {
+		fprintf(stderr, "Cursor at (%ld, " "%ld).\n", ccol, crow);
+	}
+#endif
 
 	/* Get the offsets to the beginnings of each line. */
 	caret = -1;
